@@ -1,7 +1,11 @@
 from django.contrib import admin
-from django.contrib.auth.admin import UserAdmin, UserChangeForm
+from django.contrib.auth.admin import UserAdmin, UserChangeForm, GroupAdmin, Group
 from django.forms import ModelForm
 from django.utils.translation import gettext_lazy as _
+from django.utils.text import Truncator
+from django.conf import settings
+from django.urls import reverse
+from django.utils.safestring import mark_safe
 
 from .models import User, Project, ProjectCategory, ProjectStatus, ProjectStage, ProjectActivity, Company
 
@@ -57,7 +61,6 @@ class ProjectCenterUserAdmin(UserAdmin):
 
     # inlines = [ApplicationInline, AttachmentsInline]
 
-
 class CompanyProjectsInline(admin.TabularInline):
     model = Project
     readonly_fields = ('last_activity', 'last_activity_date')
@@ -75,7 +78,7 @@ class CompanyProjectsInline(admin.TabularInline):
 
 class CompanyUsersInline(admin.TabularInline):
     model = User
-    # readonly_fields = ('jobId', 'jobTitle', 'created',)
+
     fields = ('first_name', 'last_name', 'email')
 
     def has_add_permission(self, request, obj=None):
@@ -146,9 +149,9 @@ class ProjectAdmin(admin.ModelAdmin):
         Restrict the list of authors to Super Users and Staff only.
         """
         if db_field.name == 'users':
-            if request.user.is_superuser or request.user.groups.filter(name='Commdep Admin').exists():
+            if request.user.is_superuser or request.user.groups.filter(name=settings.PROJECT_CENTER_ADMINISTRATOR_GROUP_NAME).exists():
                 """Do we filter for admins?"""
-                kwargs['queryset'] = User.objects.filter(is_active=True, is_staff=True, company=self.instance.company)
+                kwargs['queryset'] = User.objects.filter(company=self.instance.company)
             else:
                 kwargs['queryset'] = User.objects.filter(is_active=True, is_staff=True, company=self.instance.company)
 
@@ -159,13 +162,19 @@ admin.site.register(Project, ProjectAdmin)
 
 
 class ProjectActivityAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name', 'project', 'user', 'date', 'get_download_link')
+    list_display_links = ['id','name']
+    list_filter = ['project']
+    list_display = ('id', 'name', 'project_link', 'user_link', 'date', 'get_download_link', 'notes_trunc')
     search_fields = ['name', 'file', ]
     ordering = ('-date',)
+    fieldsets = (
+
+        (_("Activity Info"), {"fields": ("name", ("user", "project"), "date", "file", "notes" )}),
+    )
 
     def get_queryset(self, request):
         qs = super(ProjectActivityAdmin, self).get_queryset(request)
-        if request.user.is_superuser or request.user.groups.filter(name='Commdep Administrator').exists():
+        if request.user.is_superuser or request.user.groups.filter(name=settings.PROJECT_CENTER_ADMINISTRATOR_GROUP_NAME).exists():
             return qs
         else:
             try:
@@ -173,26 +182,59 @@ class ProjectActivityAdmin(admin.ModelAdmin):
             except:
                 return None
 
+    def formfield_for_foreignkey(self, db_field, request, **kwargs):
+        """
+            For non-superusers, restrict projects to those in same company
+        """
+        if db_field.name == 'project':
+            if request.user.is_superuser or request.user.groups.filter(name=settings.PROJECT_CENTER_ADMINISTRATOR_GROUP_NAME).exists():
+                """Do we filter for admins?"""
+                kwargs['queryset'] = Project.objects.all()
+            else:
+                kwargs['queryset'] = Project.objects.filter(company=request.user.company)
+
+        return super(ProjectActivityAdmin, self).formfield_for_foreignkey(db_field, request, **kwargs)
+
+    def notes_trunc(self, obj):
+        return Truncator(obj.notes).words(5)
+
+    notes_trunc.short_description = 'Notes'
+
+    def project_link(self, obj):
+        return mark_safe('<a href="{}">{}</a>'.format(
+            reverse("admin:project_center_project_change", args=(obj.project.pk,)),
+            obj.project.title
+        ))
+
+    project_link.short_description = 'Project'
+
+    def user_link(self, obj):
+        return mark_safe('<a href="{}">{}</a>'.format(
+            reverse("admin:project_center_user_change", args=(obj.user.pk,)),
+            obj.user.get_full_name()
+        ))
+
+    user_link.short_description = 'User'
 
 admin.site.register(ProjectActivity, ProjectActivityAdmin)
 
 
 class ProjectCategoryAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name')
+    list_display = ('id', 'name', 'display')
 
 
 admin.site.register(ProjectCategory, ProjectCategoryAdmin)
 
 
 class ProjectStatusAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name')
+    list_display = ('id', 'name', 'display')
 
 
 admin.site.register(ProjectStatus, ProjectStatusAdmin)
 
 
 class ProjectStageAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name')
+    list_display = ('id', 'name', 'display')
 
 
 admin.site.register(ProjectStage, ProjectStageAdmin)
