@@ -84,8 +84,8 @@ class Company(models.Model):
     name = models.CharField(_('Company Name'), max_length=100, blank=False)
 
     class Meta:
-        verbose_name = 'Company'
-        verbose_name_plural = "Companies"
+        verbose_name = 'Project Company'
+        verbose_name_plural = "Project Companies"
         app_label = 'project_center'
 
     def __str__(self):
@@ -114,8 +114,8 @@ class User(AbstractUser):
 
     class Meta(object):
         app_label = 'project_center'
-        verbose_name = _('User')
-        verbose_name_plural = _('Users')
+        verbose_name = _('Project User')
+        verbose_name_plural = _('Project Users')
 
     def _get_FIELD_display(self, field):
         field = super()._get_FIELD_display(field)
@@ -138,6 +138,7 @@ class User(AbstractUser):
 class ProjectCategory(models.Model):
     import_id = models.IntegerField(_('Import ID'), blank=True, null=True, default=None, help_text='Import ID')
     name = models.CharField(_('Category Name'), max_length=255, blank=False, help_text='Category Name')
+    display = models.BooleanField(default=True)
 
     class Meta(object):
         app_label = 'project_center'
@@ -151,6 +152,7 @@ class ProjectCategory(models.Model):
 class ProjectStatus(models.Model):
     import_id = models.IntegerField(_('Import ID'), blank=True, null=True, default=None, help_text='Import ID')
     name = models.CharField(_('Status Name'), max_length=255, blank=False, help_text='Status Name')
+    display = models.BooleanField(default=True)
 
     class Meta(object):
         app_label = 'project_center'
@@ -164,6 +166,7 @@ class ProjectStatus(models.Model):
 class ProjectStage(models.Model):
     import_id = models.IntegerField(_('Import ID'), blank=True, null=True, default=None, help_text='Import ID')
     name = models.CharField(_('Stage Name'), max_length=255, blank=False, help_text='Stage Name')
+    display = models.BooleanField(default=True)
 
     class Meta(object):
         app_label = 'project_center'
@@ -221,6 +224,7 @@ class ProjectActivity(models.Model):
     project = models.ForeignKey(Project, blank=True, null=True, default=None, on_delete=models.SET_NULL)
     date = models.DateTimeField(_('Activity Date'), blank=True, null=True, help_text='Activity Date')
     file = models.FileField(upload_to=activity_file_directory_path, blank=True, null=True)
+    notes = models.TextField(blank=True, null=True)
 
     class Meta(object):
         app_label = 'project_center'
